@@ -9,7 +9,7 @@ Crypt::Rijndael - Crypt::CBC compliant Rijndael encryption module
  # keysize() is 32, but 24 and 16 are also possible
  # blocksize() is 16
 
- $cipher = Crypt::Rijndael->new( "a" x 32, Crypt::Rijndael::MODE_CBC() );
+ $cipher = Crypt::Rijndael->new( "a" x 32, Crypt::Rijndael::MODE_CBC );
 
  $cipher->set_iv($iv);
  $crypted = $cipher->encrypt($plaintext);
@@ -29,12 +29,9 @@ package Crypt::Rijndael;
 use strict;
 use vars qw( $VERSION @ISA );
 
-use warnings;
-no warnings;
-
 require DynaLoader;
 
-$VERSION = '1.07_02';
+$VERSION = '1.02';
 @ISA = qw/DynaLoader/;
 
 bootstrap Crypt::Rijndael $VERSION;
@@ -52,7 +49,7 @@ algorithm actually supports any blocksize that is any multiple of
 our bytes.  128 bits, is however, the AES-specified block size,
 so this is all we support.
 
-=item $cipher = Crypt::Rijndael->new( $key [, $mode] )
+=item $cipher = new $key [, $mode]
 
 Create a new C<Crypt::Rijndael> cipher object with the given key
 (which must be 128, 192 or 256 bits long). The additional C<$mode>
@@ -97,8 +94,6 @@ Use these constants to select the cipher type:
 
 =item MODE_OFB - Output feedback
 
-=item MODE_PCBC - ignore this one for now :)
-
 =back
 
 =head1 SEE ALSO
@@ -120,7 +115,7 @@ and has been selected as the US Government's Advanced Encryption Standard.
 
 =head1 LICENSE
 
-This software is licensed under the Lesser GNU Public License. See the included
+This software is licensed under the GNU Public License. See the included
 COPYING file for details.
 
 =cut
